@@ -455,7 +455,8 @@ class MainApplication(ttk.Frame):
         self.view_menu.add_checkbutton(label="Fullscreen",
                                        command=self.toggle_fullscreen,
                                        accelerator="F11")
-        self.parent.bind("<F11>", lambda e: self.toggle_fullscreen())
+        if platform.system() != "Darwin":
+            self.parent.bind("<F11>", lambda e: self.toggle_fullscreen())
 
         if platform.system() != "Darwin":
             self.file_menu.add_command(label="Quit",
@@ -467,8 +468,8 @@ class MainApplication(ttk.Frame):
                 label="About",
                 command=lambda: HelpDialogue(self.master),
                 accelerator="F1")
+            self.parent.bind("<F1>", lambda e: HelpDialogue(self.master))
 
-        self.parent.bind("<F1>", lambda e: HelpDialogue(self.master))
         self.parent.bind(f"<{modifier}-q>",
                          lambda e: self.quit())
 
@@ -819,7 +820,7 @@ class MainApplication(ttk.Frame):
     def show_image(self, nr=0):
         try:
             if nr is None:
-                nr = 0
+                nr = -1
             if nr == -1:
                 im = Image.open(os.path.abspath(os.path.join(
             os.path.split(__file__)[0], "no_album.png")))
@@ -875,14 +876,7 @@ class MainApplication(ttk.Frame):
         # Clear current state
         self.parent.title("ZAP")
         self.hide_image()
-        im = Image.open(os.path.abspath(os.path.join(
-            os.path.split(__file__)[0], "no_album.png")))
-        im = im.resize((self.size[1], self.size[1]), Image.LANCZOS)
-        self.canvas.image = ImageTk.PhotoImage(im)
-        im.close()
-        self.canvas_image = self.canvas.create_image(
-            self.canvas.width/2, self.canvas.height/2,
-            image=self.canvas.image, anchor="center")
+        self.show_image(-1)
         self.loaded_album = None
         if self.playing_track_id is not None:
             self.pause()
@@ -1350,6 +1344,9 @@ def run():
     root.lift()
     root.focus_force()
     root.protocol('WM_DELETE_WINDOW', app.quit)
+    root.geometry(f"{WIDTH-1}x{HEIGHT-1}")  # hack for removing empty scrollbar
+    root.update_idletasks()
+    root.geometry(f"{WIDTH}x{HEIGHT}")
 
     try:
         app.load_album(os.path.abspath(sys.argv[1]))
